@@ -1,7 +1,13 @@
 package Ocsinventory::Agent::Backend::OS::Linux::Distro::NonLSB::Redhat;
 use strict;
 
-sub check {-f "/etc/redhat-release" && !readlink ("/etc/redhat-release")}
+sub check {
+    -f "/etc/redhat-release"
+      &&
+    !readlink ("/etc/redhat-release")
+      && !
+    !-f "/etc/vmware-release"
+}
 
 ####
 sub findRelease {
